import fetch from 'node-fetch';
import 'dotenv/config';
import express from "express";
import cors from 'cors';
import * as paypal from "./paypal-api.js";
const {PORT = 8888} = process.env;

const app = express();
app.set("view engine", "ejs");
app.use(
  cors({
    origin: 'https://communityservices.directoryofaustralia.com.au',
  })
);
app.use(express.static("public"));




// render checkout page with client id & unique client token
app.get("/googlepay/", async (req, res) => {
  const clientId = process.env.PAYPAL_CLIENT_ID;
  const merchantId = process.env.PAYPAL_MERCHANT_ID;
  const clientSecret = process.env.PAYPAL_CLIENT_SECRET;
  try {
    if (!clientId || !merchantId ||  !clientSecret){
      throw new Error("Client Id or App Secret or Merchant Id is missing." + clientId + " <--");
    }
    const clientToken = await paypal.generateClientToken();
    res.render("checkout", { clientId, clientToken, merchantId });
  } catch (err) {
    res.status(500).send(err.message);
  }
});

// create order
app.post("/googlepay/api/orders", async (req, res) => {
	var keyName1 = req.body;
	console.log(keyName1);
  try {
    const order = await paypal.createOrder();
    res.json(order);
  } catch (err) {
    res.status(500).send(err.message);
  }
});

// Get order
app.post("/googlepay/api/orders/:orderID", async (req, res) => {
  const { orderID } = req.params;
  try {
    const order = await paypal.getOrder(orderID);
    res.json(order);
  } catch (err) {
    res.status(500).send(err.message);
  }
});

// capture payment
app.post("/googlepay/api/orders/:orderID/capture", async (req, res) => {
  const { orderID } = req.params;
  try {
    const captureData = await paypal.capturePayment(orderID);
    res.json(captureData);
  } catch (err) {
    res.status(500).send(err.message);
  }
});

// health check
app.get("/googlepay/check" ,(req,res) => {
  res.json({
    message: "ok",
    env: process.env.NODE_ENV, 
    baseUrl: process.env.BASE_URL
  })
})

app.listen(PORT, () => {
  console.log(`Server listening at http://localhost:${PORT}/`);
});
